---
lang: en
title: 'API docs: core.application'
keywords: LoopBack 4.0, LoopBack 4, Node.js, TypeScript, OpenAPI
sidebar: lb4_sidebar
editurl: https://github.com/loopbackio/loopback-next/tree/master/packages/core
permalink: /doc/en/lb4/apidocs.core.application.html
---

<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [@loopback/core](./core.md) &gt; [Application](./core.application.md)

## Application class

Application is the container for various types of artifacts, such as components, servers, controllers, repositories, datasources, connectors, and models.

**Signature:**

```typescript
export declare class Application extends Context implements LifeCycleObserver 
```
**Extends:** [Context](./context.context.md)

**Implements:** [LifeCycleObserver](./core.lifecycleobserver.md)

## Constructors

<table><thead><tr><th>

Constructor


</th><th>

Modifiers


</th><th>

Description


</th></tr></thead>
<tbody><tr><td>

[(constructor)(parent)](./core.application._constructor_.md)


</td><td>


</td><td>

Create an application with the given parent context


</td></tr>
<tr><td>

[(constructor)(config, parent)](./core.application._constructor__1.md)


</td><td>


</td><td>

Create an application with the given configuration and parent context


</td></tr>
</tbody></table>

## Properties

<table><thead><tr><th>

Property


</th><th>

Modifiers


</th><th>

Type


</th><th>

Description


</th></tr></thead>
<tbody><tr><td>

[options](./core.application.options.md)


</td><td>

`readonly`


</td><td>

[ApplicationConfig](./core.applicationconfig.md)


</td><td>


</td></tr>
<tr><td>

[state](./core.application.state.md)


</td><td>

`readonly`


</td><td>

string


</td><td>

Get the state of the application. The initial state is `created` and it can transition as follows by `start` and `stop`<!-- -->:

1. start - !started -<!-- -->&gt; starting -<!-- -->&gt; started - started -<!-- -->&gt; started (no-op) 2. stop - (started \| initialized) -<!-- -->&gt; stopping -<!-- -->&gt; stopped - ! (started \|\| initialized) -<!-- -->&gt; stopped (no-op)

Two types of states are expected: - stable, such as `started` and `stopped` - in process, such as `booting` and `starting`

Operations such as `start` and `stop` can only be called at a stable state. The logic should immediately set the state to a new one indicating work in process, such as `starting` and `stopping`<!-- -->.


</td></tr>
</tbody></table>

## Methods

<table><thead><tr><th>

Method


</th><th>

Modifiers


</th><th>

Description


</th></tr></thead>
<tbody><tr><td>

[assertInStates(op, states)](./core.application.assertinstates.md)


</td><td>

`protected`


</td><td>

Assert current state of the application to be one of the expected values


</td></tr>
<tr><td>

[assertNotInProcess(op)](./core.application.assertnotinprocess.md)


</td><td>

`protected`


</td><td>

Assert there is no other operation is in progress, i.e., the state is not `*ing`<!-- -->, such as `starting` or `stopping`<!-- -->.


</td></tr>
<tr><td>

[awaitState(state)](./core.application.awaitstate.md)


</td><td>

`protected`


</td><td>


</td></tr>
<tr><td>

[component(componentCtor, nameOrOptions)](./core.application.component.md)


</td><td>


</td><td>

Add a component to this application and register extensions such as controllers, providers, and servers from the component.


</td></tr>
<tr><td>

[controller(controllerCtor, nameOrOptions)](./core.application.controller.md)


</td><td>


</td><td>

Register a controller class with this application.


</td></tr>
<tr><td>

[getServer(target)](./core.application.getserver.md)


</td><td>


</td><td>

Retrieve the singleton instance for a bound server.


</td></tr>
<tr><td>

[init()](./core.application.init.md)


</td><td>


</td><td>

Initialize the application, and all of its registered observers. The application state is checked to ensure the integrity of `initialize`<!-- -->.

If the application is already initialized, no operation is performed.

This method is automatically invoked by `start()` if the application is not initialized.


</td></tr>
<tr><td>

[interceptor(interceptor, nameOrOptions)](./core.application.interceptor.md)


</td><td>


</td><td>

Register an interceptor


</td></tr>
<tr><td>

[lifeCycleObserver(ctor, nameOrOptions)](./core.application.lifecycleobserver.md)


</td><td>


</td><td>

Register a life cycle observer class


</td></tr>
<tr><td>

[onInit(fn)](./core.application.oninit.md)


</td><td>


</td><td>

Register a function to be called when the application initializes.

This is a shortcut for adding a binding for a LifeCycleObserver implementing a `init()` method.


</td></tr>
<tr><td>

[onStart(fn)](./core.application.onstart.md)


</td><td>


</td><td>

Register a function to be called when the application starts.

This is a shortcut for adding a binding for a LifeCycleObserver implementing a `start()` method.


</td></tr>
<tr><td>

[onStop(fn)](./core.application.onstop.md)


</td><td>


</td><td>

Register a function to be called when the application starts.

This is a shortcut for adding a binding for a LifeCycleObserver implementing a `start()` method.


</td></tr>
<tr><td>

[server(ctor, nameOrOptions)](./core.application.server.md)


</td><td>


</td><td>

Bind a Server constructor to the Application's master context. Each server constructor added in this way must provide a unique prefix to prevent binding overlap.


</td></tr>
<tr><td>

[servers(ctors)](./core.application.servers.md)


</td><td>


</td><td>

Bind an array of Server constructors to the Application's master context. Each server added in this way will automatically be named based on the class constructor name with the "servers." prefix.


</td></tr>
<tr><td>

[service(cls, nameOrOptions)](./core.application.service.md)


</td><td>


</td><td>

Add a service to this application.


</td></tr>
<tr><td>

[setMetadata(metadata)](./core.application.setmetadata.md)


</td><td>


</td><td>

Set application metadata. `@loopback/boot` calls this method to populate the metadata from `package.json`<!-- -->.


</td></tr>
<tr><td>

[setState(state)](./core.application.setstate.md)


</td><td>

`protected`


</td><td>

Transition the application to a new state and emit an event


</td></tr>
<tr><td>

[setupShutdown()](./core.application.setupshutdown.md)


</td><td>

`protected`


</td><td>

Set up signals that are captured to shutdown the application


</td></tr>
<tr><td>

[start()](./core.application.start.md)


</td><td>


</td><td>

Start the application, and all of its registered observers. The application state is checked to ensure the integrity of `start`<!-- -->.

If the application is not initialized, it calls first `init()` to initialize the application. This only happens if `start()` is called for the first time.

If the application is already started, no operation is performed.


</td></tr>
<tr><td>

[stop()](./core.application.stop.md)


</td><td>


</td><td>

Stop the application instance and all of its registered observers. The application state is checked to ensure the integrity of `stop`<!-- -->.

If the application is already stopped or not started, no operation is performed.


</td></tr>
</tbody></table>

